//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by PasswordSafe.rc
//
#define IDR_ACCS                        100
#define IDR_MAINFRAME                   101
#define IDR_MAINMENU                    102
#define IDR_FILTERACCELERATOR           103
#define IDD_ABOUTBOX                    110
#define IDD_ADVANCED                    112
#define IDD_COLUMNCHOOSER               114
#define IDD_COMPARE_RESULTS             115
#define IDD_CONFIRMDELETE_DIALOG        116
#define IDD_CREATE_SHORTCUT             117
#define IDD_CRYPTKEYENTRY               118
#define IDD_DISPLAY_EXPIRED_ENTRIES     119
#define IDD_DLG_PWHIST                  120
#define IDD_ADVANCEDCOMPSYNCH           121
#define IDD_EDIT_SHORTCUT               122
#define IDD_IMPORT_TEXT                 125
#define IDD_IMPORT_XML                  126
#define IDD_KEYCHANGE_DIALOG            127
#define IDD_PASSKEYENTRY                130
#define IDD_PASSKEYENTRY_FIRST          131
#define IDD_PASSKEYENTRY_WITHEXIT       132
#define IDD_PASSKEYSETUP                133
#define IDD_PASSWORDSAFE_DIALOG         134
#define IDD_PROPERTIES                  136
#define IDD_PS_BACKUP                   137
#define IDD_PS_DISPLAY                  138
#define IDD_PS_MISC                     139
#define IDD_PS_PASSWORDHISTORY          140
#define IDD_PASSWORDPOLICY              141
#define IDD_PS_SECURITY                 142
#define IDD_PS_SYSTEM                   143
#define IDD_QUERYSETDEF                 144
#define IDD_SECURECLEAR                 145
#define IDD_TRYAGAIN                    146
#define IDD_PWFONTDIALOG                148
#define IDD_SAMPLETEXT                  149
#define IDD_SETFILTERS                  150
#define IDD_FILTER_STRING               151
#define IDD_FILTER_PASSWORD             152
#define IDD_FILTER_INTEGER              153
#define IDD_FILTER_DATE                 154
#define IDD_FILTER_BOOL                 155
#define IDD_FILTER_ENTRYTYPE            156
#define IDD_VIEWREPORT                  157
#define IDD_MANAGEFILTERS               158
#define IDD_PASSWORDSUBSET              159
#define IDD_VKEYBOARD                   160
#define IDD_FILTER_DCA                  161
#define IDD_DUMPSELECTOR                162
#define IDD_FILTER_ENTRYSTATUS          163
#define IDD_DISPLAYFSBKUPFILES          164
#define IDD_FILTER_SIZE                 165
#define IDR_POPRESETCOLUMNWIDTH         168
#define IDR_POPFIND                     169
#define IDR_POPCOLUMNS                  170
#define IDR_POPEDITVIEWORIGINAL         171
#define IDR_POPCOPYTOORIGINAL           172
#define IDR_POPCUSTOMIZETOOLBAR         173
#define IDR_POPEDITGROUP                174
#define IDR_POPEDITMENU                 175
#define IDR_POPTRAY                     176
#define IDR_POPTREE                     177
#define IDR_POPRIGHTDRAG                178
#define IDR_POPRESETSHORTCUT            179
#define IDI_CORNERICON                  180
#define IDI_LOCKEDICON                  181
#define IDI_MBASKICON                   182
#define IDI_MBINFOICON                  183
#define IDI_MBSTOPICON                  184
#define IDI_MBWARNICON                  185
#define IDI_ALIAS                       186
#define IDI_ABASE                       187
#define IDI_ABASE_EXPIRED               188
#define IDI_ABASE_WARNEXPIRED           189
#define IDI_NORMAL                      190
#define IDI_NORMAL_EXPIRED              191
#define IDI_NORMAL_WARNEXPIRED          192
#define IDI_SBASE                       193
#define IDI_SBASE_EXPIRED               194
#define IDI_SBASE_WARNEXPIRED           195
#define IDI_SHORTCUT                    196
#define IDI_TRAY                        205
#define IDI_TRAY_BLUE                   206
#define IDI_TRAY_WHITE                  207
#define IDI_TRAY_YELLOW                 208
#define IDI_UNLOCKEDICON                209
#define IDR_POPLANGUAGES                210
#define IDR_POPCOPYALLTOORIGINAL        211
#define IDB_CLOGO                       220
#define IDB_CLOGO_SMALL                 221
#define IDB_PSLOGO                      223
#define IDB_PWSDB                       224
#define IDB_ALIAS                       230
#define IDB_ABASE                       231
#define IDB_ABASE_EXPIRED               232
#define IDB_ABASE_WARNEXPIRED           233
#define IDB_GROUP                       234
#define IDB_NORMAL                      235
#define IDB_NORMAL_EXPIRED              236
#define IDB_NORMAL_WARNEXPIRED          237
#define IDB_SHORTCUT                    238
#define IDB_SBASE                       239
#define IDB_SBASE_EXPIRED               240
#define IDB_SBASE_WARNEXPIRED           241
#define IDB_FINDADVANCEDON_CLASSIC      242
#define IDB_FINDADVANCEDON_NEW          243
#define IDB_FINDADVANCED_CLASSIC        250
#define IDB_FINDADVANCED_NEW            251
#define IDB_FINDCASE_I_CLASSIC          252
#define IDB_FINDCASE_I_NEW              253
#define IDB_FINDCASE_S_CLASSIC          254
#define IDB_FINDCASE_S_NEW              255
#define IDB_FINDCLEAR_CLASSIC           256
#define IDB_FINDCLEAR_NEW               257
#define IDB_FINDCLOSE_CLASSIC           258
#define IDB_FINDCLOSE_NEW               259
#define IDB_FINDREPORT_CLASSIC          260
#define IDB_FINDREPORT_NEW              261
#define IDB_FINDCTRLPLACEHOLDER         262
#define IDB_ABOUT_CLASSIC               280
#define IDB_ABOUT_NEW                   281
#define IDB_ABOUT_NEW_D                 282
#define IDB_ADD_CLASSIC                 283
#define IDB_ADD_NEW                     284
#define IDB_ADD_NEW_D                   285
#define IDB_AUTOTYPE_CLASSIC            286
#define IDB_AUTOTYPE_NEW                287
#define IDB_AUTOTYPE_NEW_D              288
#define IDB_BACKUPSAFE_CLASSIC          289
#define IDB_BACKUPSAFE_NEW              290
#define IDB_BACKUPSAFE_NEW_D            291
#define IDB_BROWSEURL_CLASSIC           292
#define IDB_BROWSEURL_NEW               293
#define IDB_BROWSEURL_NEW_D             294
#define IDB_CHANGECOMBO_CLASSIC         295
#define IDB_CHANGECOMBO_NEW             296
#define IDB_CHANGECOMBO_NEW_D           297
#define IDB_CHANGEFONTMENU_CLASSIC      298
#define IDB_CHANGEFONTMENU_NEW          299
#define IDB_CHANGEFONTMENU_NEW_D        300
#define IDB_CLEARCLIPBOARD_CLASSIC      301
#define IDB_CLEARCLIPBOARD_NEW          302
#define IDB_CLEARCLIPBOARD_NEW_D        303
#define IDB_CLOSE_CLASSIC               304
#define IDB_CLOSE_NEW                   305
#define IDB_CLOSE_NEW_D                 306
#define IDB_COLLAPSEALL_CLASSIC         307
#define IDB_COLLAPSEALL_NEW             308
#define IDB_COLLAPSEALL_NEW_D           309
#define IDB_COMPARE_CLASSIC             310
#define IDB_COMPARE_NEW                 311
#define IDB_COMPARE_NEW_D               312
#define IDB_COPYNOTES_CLASSIC           313
#define IDB_COPYNOTES_NEW               314
#define IDB_COPYNOTES_NEW_D             315
#define IDB_COPYPASSWORD_CLASSIC        317
#define IDB_COPYPASSWORD_NEW            318
#define IDB_COPYPASSWORD_NEW_D          319
#define IDB_COPYUSER_CLASSIC            320
#define IDB_COPYUSER_NEW                321
#define IDB_COPYUSER_NEW_D              322
#define IDB_CREATESHORTCUT_CLASSIC      323
#define IDB_CREATESHORTCUT_NEW          324
#define IDB_CREATESHORTCUT_NEW_D        325
#define IDB_DELETE_CLASSIC              326
#define IDB_DELETE_NEW                  327
#define IDB_DELETE_NEW_D                328
#define IDB_DUPLICATE_CLASSIC           329
#define IDB_DUPLICATE_NEW               330
#define IDB_DUPLICATE_NEW_D             331
#define IDB_EXIT_CLASSIC                332
#define IDB_EXIT_NEW                    333
#define IDB_EXIT_NEW_D                  334
#define IDB_EXPANDALL_CLASSIC           335
#define IDB_EXPANDALL_NEW               336
#define IDB_EXPANDALL_NEW_D             337
#define IDB_EXPORTTEXT_CLASSIC          338
#define IDB_EXPORTTEXT_NEW              339
#define IDB_EXPORTTEXT_NEW_D            340
#define IDB_EXPORTXML_CLASSIC           341
#define IDB_EXPORTXML_NEW               342
#define IDB_EXPORTXML_NEW_D             343
#define IDB_FIND_CLASSIC                344
#define IDB_FIND_NEW                    345
#define IDB_FIND_NEW_D                  346
#define IDB_GROUPENTER_CLASSIC          347
#define IDB_GROUPENTER_NEW              348
#define IDB_GROUPENTER_NEW_D            349
#define IDB_HELP_CLASSIC                350
#define IDB_HELP_NEW                    351
#define IDB_HELP_NEW_D                  352
#define IDB_IMPORTTEXT_CLASSIC          353
#define IDB_IMPORTTEXT_NEW              354
#define IDB_IMPORTTEXT_NEW_D            355
#define IDB_IMPORTXML_CLASSIC           356
#define IDB_IMPORTXML_NEW               357
#define IDB_IMPORTXML_NEW_D             358
#define IDB_LISTTREE_CLASSIC            359
#define IDB_LISTTREE_NEW                360
#define IDB_LISTTREE_NEW_D              361
#define IDB_MERGE_CLASSIC               362
#define IDB_MERGE_NEW                   363
#define IDB_MERGE_NEW_D                 364
#define IDB_NEW_CLASSIC                 365
#define IDB_NEW_NEW                     366
#define IDB_NEW_NEW_D                   367
#define IDB_OPEN_CLASSIC                368
#define IDB_OPEN_NEW                    369
#define IDB_OPEN_NEW_D                  370
#define IDB_OPTIONS_CLASSIC             371
#define IDB_OPTIONS_NEW                 372
#define IDB_OPTIONS_NEW_D               373
#define IDB_PROPERTIES_CLASSIC          374
#define IDB_PROPERTIES_NEW              375
#define IDB_PROPERTIES_NEW_D            376
#define IDB_RESTORE_CLASSIC             377
#define IDB_RESTORE_NEW                 378
#define IDB_RESTORE_NEW_D               379
#define IDB_SAVE_CLASSIC                381
#define IDB_SAVE_NEW                    382
#define IDB_SAVE_NEW_D                  383
#define IDB_SAVEAS_CLASSIC              384
#define IDB_SAVEAS_NEW                  385
#define IDB_SAVEAS_NEW_D                386
#define IDB_SENDEMAIL_CLASSIC           387
#define IDB_SENDEMAIL_NEW               388
#define IDB_SENDEMAIL_NEW_D             389
#define IDB_TRAYLOCK_CLASSIC            390
#define IDB_TRAYLOCK_NEW                391
#define IDB_TRAYLOCK_NEW_D              392
#define IDB_TRAYUNLOCK_CLASSIC          393
#define IDB_TRAYUNLOCK_NEW              394
#define IDB_TRAYUNLOCK_NEW_D            395
#define IDB_VALIDATE_CLASSIC            396
#define IDB_VALIDATE_NEW                397
#define IDB_VALIDATE_NEW_D              398
#define IDB_VIEWEDIT_CLASSIC            399
#define IDB_VIEWEDIT_NEW                400
#define IDB_VIEWEDIT_NEW_D              401
#define IDB_VIEWREPORTS_CLASSIC         402
#define IDB_VIEWREPORTS_NEW             403
#define IDB_VIEWREPORTS_NEW_D           404
#define IDB_CHANGEPSWDFONTMENU_CLASSIC  405
#define IDB_CHANGEPSWDFONTMENU_NEW      406
#define IDB_CHANGEPSWDFONTMENU_NEW_D    407
#define IDB_EXPORT_CLASSIC              408
#define IDB_EXPORT_NEW                  409
#define IDB_EXPORT_NEW_D                410
#define IDB_IMPORT_CLASSIC              411
#define IDB_IMPORT_NEW                  412
#define IDB_IMPORT_NEW_D                413
#define IDB_APPLYFILTERS_CLASSIC        414
#define IDB_APPLYFILTERS_NEW            415
#define IDB_APPLYFILTERS_NEW_D          416
#define IDB_SETFILTERS_CLASSIC          417
#define IDB_SETFILTERS_NEW              418
#define IDB_SETFILTERS_NEW_D            419
#define IDB_MANAGEFILTERS_CLASSIC       420
#define IDB_MANAGEFILTERS_NEW           421
#define IDB_MANAGEFILTERS_NEW_D         422
#define IDB_CUSTOMIZETBAR_CLASSIC       423
#define IDB_CUSTOMIZETBAR_NEW           424
#define IDB_FILTER_ACTIVE               425
#define IDB_CHECKED                     426
#define IDB_UNCHECKED                   427
#define IDB_EMPTY                       428
#define IDB_BLANK                       429
#define IDB_DRAGGROUP_NEW               431
#define IDB_DRAGTITLE_NEW               432
#define IDB_DRAGUSER_NEW                433
#define IDB_DRAGPASSWORD_NEW            434
#define IDB_DRAGNOTES_NEW               435
#define IDB_DRAGURL_NEW                 436
#define IDB_DRAGGROUPX_NEW              437
#define IDB_DRAGTITLEX_NEW              438
#define IDB_DRAGUSERX_NEW               439
#define IDB_DRAGPASSWORDX_NEW           440
#define IDB_DRAGNOTESX_NEW              441
#define IDB_DRAGURLX_NEW                442
#define IDB_PASSWORDCHARS_CLASSIC       443
#define IDB_PASSWORDCHARS_NEW           444
#define IDB_PASSWORDCHARS_NEW_D         445
#define IDB_BROWSEURLPLUS_CLASSIC       446
#define IDB_BROWSEURLPLUS_NEW           447
#define IDB_BROWSEURLPLUS_NEW_D         448
#define IDB_RUNCMD_CLASSIC              449
#define IDB_RUNCMD_NEW                  450
#define IDB_RUNCMD_NEW_D                451
#define IDD_PS_SHORTCUTS                452
#define IDB_DRAGGROUP_CLASSIC           453
#define IDB_DRAGTITLE_CLASSIC           454
#define IDB_DRAGUSER_CLASSIC            455
#define IDB_DRAGPASSWORD_CLASSIC        456
#define IDB_DRAGNOTES_CLASSIC           457
#define IDB_DRAGURL_CLASSIC             458
#define IDB_DRAGGROUPX_CLASSIC          459
#define IDB_DRAGTITLEX_CLASSIC          460
#define IDB_DRAGUSERX_CLASSIC           461
#define IDB_DRAGPASSWORDX_CLASSIC       462
#define IDB_DRAGNOTESX_CLASSIC          463
#define IDB_DRAGURLX_CLASSIC            464
#define IDD_ADDEDIT_BASIC               465
#define IDD_ADDEDIT_ADDITIONAL          466
#define IDD_ADDEDIT_DATETIMES           467
#define IDD_ADDEDIT_PASSWORDPOLICY      468
#define IDB_EXCLAMATION                 470
#define IDB_CHANGEVKBDFONTMENU_CLASSIC  471
#define IDB_CHANGEVKBDFONTMENU_NEW      472
#define IDB_CHANGEVKBDFONTMENU_NEW_D    473
#define IDB_DRAGEMAIL_NEW               474
#define IDB_DRAGEMAILX_NEW              475
#define IDB_DRAGEMAIL_CLASSIC           476
#define IDB_DRAGEMAILX_CLASSIC          477
#define IDB_UNDO_CLASSIC                478
#define IDD_ALIAS_PSWDCHANGE            479
#define IDB_REDO_CLASSIC                480
#define IDB_UNDO_NEW                    481
#define IDB_REDO_NEW                    482
#define IDB_UNDO_NEW_D                  483
#define IDB_REDO_NEW_D                  484
#define IDB_SYNCHRONIZE_CLASSIC         485
#define IDB_SYNCHRONIZE_NEW             486
#define IDB_SYNCHRONIZE_NEW_D           487
#define IDB_ADDGROUP_CLASSIC            488
#define IDB_ADDGROUP_NEW                489
#define IDB_ADDGROUP_NEW_D              490
#define IDB_DUPLICATEGROUP_CLASSIC      491
#define IDB_DUPLICATEGROUP_NEW          492
#define IDB_DUPLICATEGROUP_NEW_D        493
#define IDD_WZADVANCED                  494
#define IDD_WZADVANCEDTOP               495
#define IDD_WZADVANCEDBOTTOM            496
#define IDD_WZSELECTDB                  497
#define IDD_WZFINISH                    498
#define IDB_DRAGAUTOX_CLASSIC           499
#define IDB_DRAGAUTOX_NEW               500
#define IDD_ADDEDIT_BASIC_SHORT         501
#define IDD_ADDEDIT_DATETIMES_SHORT     502
#define IDD_ADDEDIT_PASSWORDPOLICY_SHORT 503
#define IDD_ADDEDIT_ADDITIONAL_SHORT    504
#define IDD_PS_BACKUP_SHORT             505
#define IDD_PS_DISPLAY_SHORT            506
#define IDD_PS_MISC_SHORT               507
#define IDD_PASSWORDPOLICY_SHORT        508
#define IDD_PS_SHORTCUTS_SHORT          509
#define IDD_PS_SYSTEM_SHORT             510
#define IDD_INPUTBOX                    511
#define IDB_CLEARFILTERS_CLASSIC        512
#define IDB_CLEARFILTERS_NEW            513
#define IDB_CLEARFILTERS_NEW_D          514
#define IDD_MANAGEPASSWORDPOLICIES      515
#define IDB_PSWD_POLICIES_CLASSIC       516
#define IDB_PSWD_POLICIES_NEW           517
#define IDB_PSWD_POLICIES_NEW_D         518
#define IDB_COPYTOCLIPBOARD_CLASSIC     519
#define IDB_COPYTOCLIPBOARD_NEW         520
#define IDR_POPCOMPAREENTRIES           521
#define IDD_SHOW_COMPARE                522
#define IDD_COMPARE_WITH                523
#define IDB_EMPTY_GROUP                 524

#define IDB_YUBI_LOGO                   525
#define IDB_YUBI_LOGO_DIS               526
#define IDD_YUBIKEY                     527

#define IDC_APPVERSION                  1000
#define IDC_VERSION                     1001
#define IDC_APPVERSION2                 1002
#define IDC_APPBUILTON                  1020
#define IDC_CREATE_DB                   1003
#define IDC_EXIT                        1004
#define IDC_PASSWORD                    1005
#define IDC_NEWPASSKEY                  1007
#define IDC_CONFIRMNEW                  1008
#define IDC_TITLE                       1009
#define IDC_USERNAME                    1010
#define IDC_NOTES                       1011
#define IDC_ITEMLIST                    1012
#define IDC_ITEMTREE                    1013
#define IDC_SHOWPASSWORD                1014
#define IDC_CLEARCHECK                  1015
#define IDC_PASSKEY                     1016
#define IDC_DELITEM                     1017
#define IDC_VERIFY                      1018
#define IDC_CONFIRMDELETE               1019
#define IDC_CONFIRMCOPY                 1021
#define IDC_TRYAGAIN                    1022
#define IDC_QUIT                        1023
#define IDC_OPEN                        1024
#define IDC_GENERATEPASSWORD            1025
#define IDC_LOCKONMINIMIZE              1026
#define IDC_DEFPWSHOWINEDIT             1028
#define IDC_USEDEFUSER                  1029
#define IDC_QUERYSETDEF                 1030
#define IDC_DEFPWSHOWINTREE             1031
#define IDC_CRYPTKEY1                   1032
#define IDC_CRYPTKEY2                   1033
#define IDC_DEFUSERNAME                 1034
#define IDC_DEFPWLENGTH                 1036
#define IDC_MESSAGE                     1037
#define IDC_QUERYCHECK                  1038
#define IDC_NEW                         1041
#define IDC_STATIC_LOGO                 1042
#define IDC_ALWAYSONTOP                 1043
#define IDC_STATIC_LOGOTEXT             1044
#define IDC_SAVEIMMEDIATELY             1045
#define IDC_PWLENSPIN                   1046
#define IDC_USELOWERCASE                1047
#define IDC_USEUPPERCASE                1048
#define IDC_USEDIGITS                   1049
#define IDC_USESYMBOLS                  1050
#define IDC_EASYVISION                  1051
#define IDC_PRONOUNCEABLE               1052
#define IDC_MINDIGITLENGTH              1053
#define IDC_MINLOWERLENGTH              1054
#define IDC_MINSYMBOLLENGTH             1055
#define IDC_MINUPPERLENGTH              1056
#define IDC_SPINLOWERCASE               1057
#define IDC_SPINUPPERCASE               1058
#define IDC_SPINDIGITS                  1059
#define IDC_SPINSYMBOLS                 1060
#define IDC_CLEARBOARDONMINIMIZE        1061
#define IDC_CLEARBOARDONEXIT            1062
#define IDC_GROUP                       1067
#define IDC_USEHEXDIGITS                1070
#define IDC_ADVANCED                    1071
#define IDC_DEFPWUSESYSTRAY             1072
#define IDC_LOCKONSCREEN                1073
#define IDC_DEFPWRECENTRYHELP           1074
#define IDC_IDLESPIN                    1075
#define IDC_IDLE_TIMEOUT                1076
#define IDC_LOCK_TIMER                  1077
#define IDC_ESC_EXITS                   1078
#define IDC_TAB                         1079
#define IDC_COMMA                       1080
#define IDC_OTHER                       1081
#define IDC_OTHER_SEPARATOR             1082
#define IDC_NO_GROUP                    1083
#define IDC_YES_GROUP                   1084
#define IDC_GROUP_NAME                  1085
#define IDC_READONLY                    1086
#define IDC_APPHOTKEY_CTRL              1087
#define IDC_APPHOTKEY_ENABLE            1088
#define IDC_DEFIMPDELIM                 1090
#define IDC_QUERYSETEXPDELIM            1091
#define IDC_WZDEFEXPDELIM               1092
#define IDC_STATIC_MAXMRUITEMS          1093
#define IDC_MAXMRUITEMS                 1094
#define IDC_STATIC_GBMRU                1095
#define IDC_MRU_ONFILEMENU              1096
#define IDC_STATIC_RESTART              1097
#define IDC_STATIC_MAXREITEMS           1098
#define IDC_MAXREITEMS                  1099
#define IDC_URL                         1100
#define IDC_AUTOTYPE                    1101
#define IDC_EMAIL                       1102
#define IDC_EXPIRYDATE                  1103
#define IDC_EXPIRYTIME                  1104
#define IDC_STATIC_CURRENT_XTIME        1105
#define IDC_RUNCMD                      1106
#define IDC_XTIME_RECUR                 1107
#define IDC_STATIC_CTIME                1108
#define IDC_CTIME                       1109
#define IDC_STATIC_PMTIME               1110
#define IDC_PMTIME                      1111
#define IDC_STATIC_ATIME                1112
#define IDC_ATIME                       1113
#define IDC_STATIC_XTIME                1114
#define IDC_XTIME                       1115
#define IDC_STATIC_RMTIME               1116
#define IDC_RMTIME                      1117
#define IDC_MAINTAINDATETIMESTAMPS      1121
#define IDC_STATIC_DTGROUP              1122
#define IDC_STATIC_DTEXPGROUP           1123
#define IDC_EXPIRED_PASSWORD_LIST       1128
#define IDC_RESPIN                      1132
#define IDC_MRUSPIN                     1133
#define IDC_PWHSPIN                     1134
#define IDC_PWHISTORY_LIST              1136
#define IDC_SAVEPWHISTORY               1137
#define IDC_MAXPWHISTORY                1138
#define IDC_DEFPWHNUM                   1139
#define IDC_COPY_OLDPW_TO_CLIPBOARD     1140
#define IDC_CLEAR_PWHIST                1141
#define IDC_SAVE_PWHIST                 1143
#define IDC_STATIC_OLDPW1               1144
#define IDC_PASSWORD2                   1149
#define IDC_CLEAR_HISTORY               1150
#define IDC_REPORT2CLIPBOARD            1151
#define IDC_ADVANCED_LIST               1152
#define IDC_ADVANCED_SELECTED           1153
#define IDC_ADVANCED_SELECTSOME         1154
#define IDC_ADVANCED_SELECTALL          1155
#define IDC_ADVANCED_DESELECTSOME       1156
#define IDC_ADVANCED_DESELECTALL        1157
#define IDC_ADVANCED_SUBGROUP_SET       1158
#define IDC_ADVANCED_SUBGROUP_NAME      1159
#define IDC_ADVANCED_SUBGROUP_FUNCTION  1160
#define IDC_ADVANCED_SUBGROUP_OBJECT    1161
#define IDC_ADVANCED_SUBGROUP_CASE      1162
#define IDC_PWH_COPY_ALL                1174
#define IDC_TREE_DISPLAY_COLLAPSED      1176
#define IDC_TREE_DISPLAY_EXPANDED       1177
#define IDC_TREE_DISPLAY_LASTSAVE       1178
#define IDC_DOUBLE_CLICK_ACTION         1181
#define IDC_PWHISTORYNOACTION           1183
#define IDC_RESETPWHISTORYOFF           1184
#define IDC_RESETPWHISTORYON            1185
#define IDC_SETMAXPWHISTORY             1186
#define IDC_STATIC_UPDATEPWHISTORY      1187
#define IDC_REGDEL                      1188
#define IDC_SETMAXPWHISTORY2            1189
#define IDC_DEFNOTESSHOWINEDIT          1190
#define IDC_DATABASENAME                1191
#define IDC_DATABASEFORMAT              1192
#define IDC_NUMGROUPS                   1193
#define IDC_NUMENTRIES                  1194
#define IDC_SAVEDBY                     1195
#define IDC_SAVEDON                     1196
#define IDC_SAVEDAPP                    1197
#define IDC_BACKUPBEFORESAVE            1199
#define IDC_DFLTBACKUPPREFIX            1200
#define IDC_USERBACKUPPREFIX            1201
#define IDC_USERBACKUPPREFIXVALUE       1202
#define IDC_BACKUPSUFFIX                1203
#define IDC_DFLTBACKUPLOCATION          1205
#define IDC_USERBACKUPOTHERLOCATION     1206
#define IDC_USERBACKUPOTHRLOCATIONVALUE 1208
#define IDC_BACKUPEXAMPLE               1209
#define IDC_BKPMAXINCSPIN               1210
#define IDC_BACKUPMAXINC                1211
#define IDC_BACKUPMAX                   1212
#define IDC_BROWSEFORLOCATION           1213
#define IDC_BROWSEFORLOCATION_BROWSER   1214
#define IDC_BROWSEFORLOCATION_EDITOR    1215
#define IDC_APPLYCONFIGCHANGES          1216
#define IDC_OTHERBROWSERLOCATION        1217
#define IDC_APPCOPYRIGHT                1218
#define IDC_OTHEREDITORLOCATION         1219
#define IDC_STARTUP                     1220
#define IDC_CONFIG_GRP                  1221
#define IDC_DATABASECOMBO               1222
#define IDC_BTN_BROWSE                  1223
#define IDC_SPCL_TXT                    1225
#define IDC_SELECTBYDATETIME            1227
#define IDC_SELECTBYDAYS                1228
#define IDC_SELECTBYNONE                1229
#define IDC_EXPDAYS                     1230
#define IDC_EXPDAYSSPIN                 1231
#define IDC_PREWARNEXPIRY               1232
#define IDC_PREEXPIRYWARNDAYS           1233
#define IDC_PREWARNEXPIRYSPIN           1234
#define IDC_DEFEXPLORERTREE             1235
#define IDC_DEFENABLEGRIDLINES          1246
#define IDC_LIST_HEADER                 1247
#define IDC_CPLIST                      1248
#define IDC_DB_DEFAULTAUTOTYPE          1249
#define IDC_MINIMIZEONAUTOTYPE          1250
#define IDC_ALTBROWSER_CMDLINE          1251
#define IDC_DEFUNSHOWINTREE             1254
#define IDC_FILEUUID                    1255
#define IDC_UNKNOWNFIELDS               1256
#define IDC_RESULTLIST                  1257
#define IDC_RESULTLISTHDR               1258
#define IDC_COMPAREORIGINALDB           1260
#define IDC_COMPARECOMPARISONDB         1261
#define IDC_SHOW_IDENTICAL_ENTRIES      1262
#define IDC_STATIC_UNK_FIELDS           1263
#define IDC_DELETECHILDREN              1264
#define IDC_RECORDUNKNOWNFIELDS         1265
#define IDC_STATIC_RECORDUNKNOWNFIELDS  1266
#define IDC_STATICGROUPRUNKNFLDS        1267
#define IDC_VIEWDEPENDENTS              1268
#define IDC_STATIC_ISANALIAS            1269
#define IDC_NEWVER_STATUS               1272
#define IDC_VISIT_WEBSITE               1273
#define IDC_RST_BLK                     1276
#define IDC_RST_BLUE                    1277
#define IDC_RST_WHITE                   1278
#define IDC_RST_YELLOW                  1279
#define IDC_SAMPLETEXT                  1283
#define IDC_TREATWHITESPACEASEMPTY      1284
#define IDC_STATIC_LC1                  1285
#define IDC_STATIC_LC2                  1286
#define IDC_STATIC_UC1                  1287
#define IDC_STATIC_UC2                  1288
#define IDC_STATIC_DG1                  1289
#define IDC_STATIC_DG2                  1290
#define IDC_STATIC_SY1                  1291
#define IDC_STATIC_SY2                  1292
#define IDC_ADDSCEXPLANATION            1293
#define IDC_EDITSCEXPLANATION           1294
#define IDC_STATIC_REMLAST              1295
#define IDC_DEFNTSHOWASTIPSINVIEWS      1296
#define IDC_REUSE_ON_CHANGE             1297
#define IDC_STATIC_LTINTERVAL_NOW       1298
#define IDC_STATIC_LTINTERVAL_ALWAYS    1299
#define IDC_DEFAULTOPENRO               1300
#define IDC_CLEARFILTERS                1301
#define IDC_DISABLEALLFILTERS           1302
#define IDC_FILTERLC                    1303
#define IDC_FILTERNAME                  1304
#define IDC_FILTERLC_HEADER             1305
#define IDC_APPLY                       1306
#define IDC_STATIC_AND                  1307
#define IDC_STRINGRULE                  1308
#define IDC_STRING1                     1309
#define IDC_STRINGCASE                  1310
#define IDC_INTEGERRULE                 1311
#define IDC_INTEGER1                    1312
#define IDC_INTEGER2                    1313
#define IDC_DATERULE                    1314
#define IDC_DATETIMEPICKER1             1315
#define IDC_DATETIMEPICKER2             1316
#define IDC_BOOLRULE                    1317
#define IDC_ENTRYTYPERULE               1318
#define IDC_ENTRYTYPE1                  1319
#define IDC_STATIC_IN                   1320
#define IDC_STATIC_DAYS                 1321
#define IDC_STATIC_STATUS               1322
#define IDC_MFILTER_FLD_COMBOBOX        1323
#define IDC_HFILTER_FLD_COMBOBOX        1324
#define IDC_PFILTER_FLD_COMBOBOX        1325
#define IDC_MFILTER_LGC_COMBOBOX        1326
#define IDC_HFILTER_LGC_COMBOBOX        1327
#define IDC_PFILTER_LGC_COMBOBOX        1328
#define IDC_FILTERPROP_HEADER           1331
#define IDC_MULTIPLEINSTANCES           1333
#define IDC_STATIC_DRAGGROUP            1334
#define IDC_STATIC_DRAGTITLE            1335
#define IDC_STATIC_DRAGUSER             1336
#define IDC_STATIC_DRAGPASSWORD         1337
#define IDC_STATIC_DRAGNOTES            1338
#define IDC_STATIC_DRAGURL              1339
#define IDC_EDITREPORT                  1340
#define IDC_FILTERNEW                   1341
#define IDC_FILTEREDIT                  1342
#define IDC_FILTERCOPY                  1343
#define IDC_FILTERDELETE                1344
#define IDC_FILTERIMPORT                1345
#define IDC_FILTEREXPORT                1346
#define IDC_FILTERPROPERTIES            1347
#define IDC_STATIC_FILTERNAME           1348
#define IDC_STATIC_GROUP                1350
#define IDC_STATIC_TITLE                1351
#define IDC_STATIC_USERNAME             1352
#define IDC_STATIC_PASSWORD             1353
#define IDC_STATIC_NOTES                1354
#define IDC_STATIC_URL                  1355
#define IDC_STATIC_EMAIL                1356
#define IDC_STATIC_AUTO                 1357
#define IDC_STATIC_RUNCMD               1358
#define IDC_SUBSET                      1359
#define IDC_GETSUBSET                   1360
#define IDC_SUBSETRESULTS               1361
#define IDC_STATICSUBSETWARNING         1362
#define IDC_DEFNOTESWRAP                1363
#define IDC_STATIC_DTSTATS              1364
#define IDC_SHORTCUTLIST                1367
#define IDC_RESETALLSHORTCUTS           1368
#define IDC_SHORTCUTHOTKEY              1369
#define IDC_STATIC_SHCTWARNING          1370
#define IDC_SHORTCUTLC_HEADER           1371
#define IDC_VKB                         1372
#define IDC_SETSAMPLETEXT               1373
#define IDC_RESETFONT                   1374
#define IDC_ENTRYPWPOLICY               1376
#define IDC_LAUNCH                      1379
#define IDC_SENDEMAIL                   1380
#define IDC_STATIC_PWH_ADD              1381
#define IDC_STATIC_PWH_EDIT             1382
#define IDC_INFO                        1383
#define IDC_TAKETESTDUMP                1384
#define IDC_DUMP_WIN32                  1385
#define IDC_DUMP_TERMINATE              1386
#define IDC_DUMP_UNEXPECTED             1387
#define IDC_DUMP_INVALIDPARAMETER       1388
#define IDC_DUMP_SIGILL                 1389
#define IDC_DUMP_SIGTERM                1390
#define IDC_DUMP_SIGABRT                1391
#define IDC_DCA1                        1392
#define IDC_DCARULE                     1393
#define IDC_STATIC_DRAGEMAIL            1394
#define IDC_ENTRYSTATUSRULE             1395
#define IDC_ENTRYSTATUS1                1396
#define IDC_HIGHLIGHTCHANGES            1397
#define IDC_IMPORT_PSWDS_ONLY           1398
#define IDC_STATIC_OR                   1399
#define IDC_STATIC_PWLEN                1400
#define IDC_STATIC_CURRENTVALUE         1401
#define IDC_RECFILELIST                 1402
#define IDC_CONTINUE                    1403
#define IDC_SELECT                      1404
#define IDC_DELETE                      1405
#define IDC_STATIC_UUID                 1407
#define IDC_UUID                        1408
#define IDC_STATIC_SIZE                 1409
#define IDC_ENTRYSIZE                   1410
#define IDC_SIZE_B                      1411
#define IDC_SIZE_KB                     1412
#define IDC_SIZE_MB                     1413
#define IDC_CHANGEBASEPSWD              1414
#define IDC_CHANGEALIASPSWD             1415
#define IDC_STATIC_BASE                 1416
#define IDC_STATIC_TEXT                 1417
#define IDC_STATIC_WHERE                1418
#define IDC_STATIC_AND2                 1419
#define IDC_STATIC_RELDESC              1420
#define IDC_MIGRATETOAPPDATA            1421
#define IDC_STATIC_CONFIGFILE           1422
#define IDC_CONFIGFILE                  1423
#define IDC_STATIC_RWSTATUS             1424
#define IDC_COPYPASSWORD                1425
#define IDC_DEFPWHIDESYSTRAY            1426
#define IDC_ADVANCED_RESET              1427
#define IDC_ENTRY                       1428
#define IDC_STATIC_PROTECTED            1429
#define IDC_DATABASE                    1430
#define IDC_VIEWREPORT                  1431
#define IDC_STATIC_WZWARNING            1432
#define IDC_STATIC_WZEXPDLM1            1433
#define IDC_STATIC_WZEXPDLM2            1434
#define IDC_STATIC_WZFILE               1435
#define IDC_STATIC_WZPROCESSING         1436
#define IDC_STATIC_WZRESULTS            1437
#define IDC_USEDEFAULTSYMBOLS           1438
#define IDC_USEOWNSYMBOLS               1439
#define IDC_OWNSYMBOLS                  1440
#define IDC_STATIC_DEFAULTSYMBOLS       1441
#define IDC_DEFAULTAUTOTYPE             1442
#define IDC_STATIC_DRAGAUTO             1443
#define IDC_COPYPSWDURL                 1444
#define IDC_STATIC_IDLEMINS             1445
#define IDC_STATIC_NUMPWSDHIST          1446
#define IDC_STATIC_DEFAUTOTYPE          1447
#define IDC_STATIC_PSWDLENGTH           1448
#define IDC_SHIFT_DOUBLE_CLICK_ACTION   1449
#define IDC_STATIC_PREFERENCES          1451
#define IDC_YUBIKEY_BTN                 1452
#define IDC_YUBIKEY_STATUS              1453
#define IDC_YUBIKEY_BTN2                1454
#define IDC_YUBIKEY2_BTN                1455
#define IDC_YUBI_PROGRESS               1456
#define IDC_YUBI_STATUS                 1457
#define IDC_STATIC_DB_PREFS_RO_WARNING  1458
#define IDC_DATABASE_NAME               1459
#define IDC_DATABASE_DESCRIPTION        1460
#define IDC_CHANGE_DESCRIPTION          1461
#define IDC_CHANGE_NAME                 1462
#define IDC_INPUTBOX_TEXT               1463
#define IDC_INPUTBOX_CHAR_COUNT         1464
#define IDC_YUBI_SN                     1465
#define IDC_YUBI_SK                     1466
#define IDC_YUBI_GEN_BN                 1467
#define IDC_BUTTON2                     1468
#define IDC_YUBI_API                    1469
#define IDC_BUTTON1                     1470
#define IDC_YUBI_SHOW_HIDE              1471
#define IDC_EDIT                        1472
#define IDC_LIST_POLICYENTRIES          1473
#define IDC_POLICYLIST                  1474
#define IDC_POLICYNAME                  1475
#define IDC_USEPWPOLICYNAME             1476
#define IDC_POLICYPROPERTIES            1477
#define IDC_POLICYENTRIES               1478
#define IDC_STATIC_POLICYDETAILS        1479
#define IDC_STATIC_POLICYENTRIES        1480
#define IDC_USENAMED_POLICY             1481
#define IDC_STATIC_NAMEDPOLICY          1482
#define IDC_POLICYNAMES_HEADER          1483
#define IDC_POLICYENTRIES_HEADER        1484
#define IDC_STATIC_COPYPSWD             1485
#define IDC_UNDO                        1486
#define IDC_REDO                        1487
#define IDC_CLEARPWHISTORY              1488
#define IDC_UPDATEPROTECTEDPWH          1489
#define IDC_SHOW_IDENTICAL_FIELDS       1490
#define IDC_ABORT                       1491
#define IDC_ENTKBSHCTHOTKEY             1492
#define IDC_ENTSHORTCUTLIST             1493
#define IDC_ENTLIST_HEADER              1494
#define IDC_HASHITERSLIDER              1495
#define IDC_STATIC_HASHITER             1496
#define IDC_STATIC_HASHITER_MIN         1497
#define IDC_STATIC_HASHITER_MAX         1498

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS

#define _APS_NEXT_RESOURCE_VALUE        528
#define _APS_NEXT_COMMAND_VALUE         30001
#define _APS_NEXT_CONTROL_VALUE         1499
#define _APS_NEXT_SYMED_VALUE           166
#endif
#endif
